pub struct Stylesheet(pub &'static str);Expand description
the wrapping type for the included tailwind source, automaticly works as a response type for the web frameworks, enabled by the features
Tuple Fields
0: &'static strImplementations